import { shallowMount } from '@vue/test-utils'
import FormInput from '../form-input/index.vue'
import HelperTooltip from "../helper-tooltip/index.vue";

const name = "test-input";

describe('FormInput.vue', () => {
  it("id atribute exist", () => {
    const wrapper = shallowMount(FormInput, {
      propsData: {
        name
      }
    });
    expect(wrapper.find(`#${name}`).exists()).toBe(true);
  });

  it('name attribute exist', () => {
    const wrapper = shallowMount(FormInput, {
      propsData: {
        name
      }
    })
    expect(wrapper.find(`input[name*="${name}"]`).exists()).toBe(true);
  })

  it("class attribute exist", () => {
    const className = "special";
    const wrapper = shallowMount(FormInput, {
      propsData: {
        name,
        className
      }
    });
    expect(wrapper.find(`.formitem.${className}`).exists()).toBe(true);
  });

  it("value is properly set", () => {
    const value = "test-value";
    const wrapper = shallowMount(FormInput, {
      propsData: {
        name,
        value
      }
    });
    expect(wrapper.find("input").element.value).toBe(value);
  });

  it("has correct label text ", () => {
    const label = "test-label";
    const wrapper = shallowMount(FormInput, {
      propsData: {
        name,
        label
      }
    });
    expect(wrapper.find("label").text()).toBe(label);
  });

  it("disabling works", () => {
    const disabled = true;
    const wrapper = shallowMount(FormInput, {
      propsData: {
        name,
        disabled
      }
    });
    expect(wrapper.find(`#${name}`).attributes('disabled')).toBe('disabled');
  });


  it("placeholder according prop", () => {
    const placeholder = 'test-placeholder';
    const wrapper = shallowMount(FormInput, {
      propsData: {
        name,
        placeholder
      }
    });
    expect(wrapper.find(`#${name}`).attributes("placeholder")).toBe(
      placeholder
    );
  });


  it("hint appeared", () => {
    const helperText = "helper-text";
    const wrapper = shallowMount(FormInput, {
      propsData: {
        name,
        helperText
      }
    });
    expect(wrapper.contains(HelperTooltip)).toBe(true);
  });

  it("has appropriate type", () => {
    const type = "password";
    const wrapper = shallowMount(FormInput, {
      propsData: {
        name,
        type
      }
    });
    expect(wrapper.find(`#${name}`).attributes("type")).toBe(type);
  });

  it("clear icon appeared", () => {
    const clearIcon = true;
    const value = "test-value";
    const wrapper = shallowMount(FormInput, {
      propsData: {
        name,
        value,
        clearIcon
      }
    });
    expect(wrapper.findAll(".formitem__clear").exists()).toBe(true);
  });

})
