import { shallowMount } from '@vue/test-utils'
import RadioGroup from "../radio-group/index.vue";
import HelperTooltip from "../helper-tooltip/index.vue";

const name = 'radio-test';
const radios = [{
  text: 'Yes',
  value: 'yes',
}, {
  text: 'No',
  value: 'no',
}, {
  text: 'Maybe',
  value: 'maybe',
}];

describe('RadioGroup.vue', () => {
  it("name atribute exist", () => {
    const wrapper = shallowMount(RadioGroup, {
      propsData: {
        name,
        radios
      }
    });
    expect(wrapper.find(`input[name*="${name}"]`).exists()).toBe(true);
  });

  it("has correct label text ", () => {
    const label = "test-label";
    const wrapper = shallowMount(RadioGroup, {
      propsData: {
        name,
        label,
        radios
      }
    });
    expect(wrapper.find("label").text()).toBe(label);
  });

  it("appropriate amount of inputs according passed prop", () => {
    const wrapper = shallowMount(RadioGroup, {
      propsData: {
        name,
        radios
      }
    });
    expect(wrapper.findAll("input").length).toBe(3);
  });

  it("hint appeared", () => {
    const helperText = "helper-text";
    const wrapper = shallowMount(RadioGroup, {
      propsData: {
        name,
        radios,
        helperText
      }
    });
    expect(wrapper.contains(HelperTooltip)).toBe(true);
  });

  it("correct input checked", () => {
    const value = 'no';
    const wrapper = shallowMount(RadioGroup, {
      propsData: {
        name,
        radios,
        value
      }
    });
    expect(wrapper.findAll("#radio-test-1:checked").length).toBe(1);
  });
})
